@@ -222,7 +222,7 @@ int ps_print_mod(f,m)
     }
 }
 /*--------------------------------------------------------------------------------- */
-int xc_print_mod(areastruct,m )
+int xc_print_mod(areastruct, m)
     Clientdata *areastruct;
     module *m;
 {
@@ -243,16 +243,17 @@ int xc_print_mod(areastruct,m )
 
 	/* Special case stuff for mulit-terminal ANSI AND, NAND, OR, NOR, XOR, and
 	   XNOR gates: */
+
 	if ((m->y_size > ICON_SIZE) && (type != BLOCK) && (type != DONT_KNOW))
 	{
 	    scale = (float)m->x_size/(float)(ICON_SIZE * ICON_SIZE/2);
 
 	    if ((type == AND) || (type == NAND))
 	    {   /* AND family - display a line to connect all inputs to the icon */
-		mid_x = (float)m->x_pos + (float)m->x_size/2.0;
+		mid_x = (float)m->x_pos + (float)m->x_size / 2.0;
 
 		//code to be attached 
-			   }
+	    }
 
 	    else if ((type == OR) || (type == NOR))
 	    {   /* OR family -- Add line to the 1st Back Curve:  */
@@ -742,85 +743,23 @@ int ps_print_sym(f, sym, x, y, x_dis, y_dis, rot, name,scale)
     }
      return(1);
 }
+
 /*--------------------------------------------------------------------------------- */
 
-int xc_print_sym(areastruct, sym, x, y, x_dis, y_dis, rot, name,scale)
+int xc_print_sym(areastruct, sym, x, y, x_dis, y_dis, rot, name, scale)
     Clientdata *areastruct;
     char *sym, *name;
     int x, y, x_dis, y_dis, rot;
-	float scale;
+    float scale;
 {
-       char* keyword;
-
-    /* print the symbol that goes with this type: */
-    switch(validate(sym))
-    {
-	case BUFFER : 
-		     keyword = "buffer";
-	              break;
-	case INVNOT_  : 
-			keyword = "invert";
-			break;
-	case NOT_  : 
-                       keyword = "buffer"; 
-                     break;
-	case AND  : 
-                     keyword = "and_gate";
-		     break;
-	case NAND : 
-                     keyword = "nand";
-		            break;
-	case OR   : 
-                     keyword = "or_gate";
-		            break;
-	case NOR  :
-                     keyword = "nor";
-		            break;
-	case XOR  :
-                     keyword = "xor_gate";
-		     break;
-	case XNOR :
-                     keyword = "xnor";
-		            break;
-
-	case INPUT_SYM : 
-                     keyword = "buffer";
-	                 break;
-	case OUTPUT_SYM :  keyword = "buffer";
-				  break;
-	 
-        case BLOCK :	keyword = "and_gate";
-			break;
-
-	case NMOS :	keyword = "nMOS4";
-			break;
-
-	case PMOS :   keyword = "pMOS4";
-			break;
-
-	case RESTR :  keyword = "resistor";
-			break;
-
-	case INDR :   keyword = "inductor";
-			break;
-
-	case CAPC :  keyword = "capacitor";
-		 	break;
-	case VAMP : keyword = "isource";
-			break;
-
-        default : keyword = "and_gate";
-	          return(0);
-	  	  break;
-
-    }
-    asg_make_instance((*areastruct), keyword, x, y, x_dis, y_dis,scale);
-    asg_make_label((*areastruct),NORMAL,x*15 ,y*15 ,name);
+    asg_make_instance(areastruct, sym, x, y, x_dis, y_dis, scale);
+    asg_make_label(areastruct, NORMAL, x * 15 , y * 15, name);
 
     return(1);
 }
 
 /*--------------------------------------------------------------------------------- */
+
 int ps_put_label(f, str, x, y)
     FILE *f;
     char *str;
@@ -828,7 +767,9 @@ int ps_put_label(f, str, x, y)
 {
     fprintf(f,"%f %f moveto (%s) show\n", x,y,str);
 }
+
 /*--------------------------------------------------------------------------------- */
+
 int ps_put_int(f, i, x, y)
     FILE *f;
     int i;
@@ -838,6 +779,7 @@ int ps_put_int(f, i, x, y)
 }
 
 /*--------------------------------------------------------------------------------- */
+
 int validate(s)
     char *s;
 {			
@@ -862,6 +804,7 @@ int validate(s)
     if (!strcmp(s, GENERIC_BLOCK)) return BLOCK;
     if (!strcmp(s, GATE_NMOS_STR)) return NMOS;
     if (!strcmp(s, GATE_VAMP_STR)) return VAMP;
+    if (!strcmp(s, GATE_MSFET_STR)) return MSFET;
     else return(DONT_KNOW);
 }
 /* Also adjust "set_default_object_size" whenever this is modified. */
