@@ -1355,7 +1355,7 @@ void unjoin()
          /* remove the path object and revise the selectlist */
 
          freeparts(selectobj, 0);
-         reviseselect(selectobj);
+         reviseselect(areastruct.selectlist, areastruct.selects, selectobj);
       }
    }
    clearselects();
