@@ -1059,9 +1059,20 @@ proc xcircuit::promptloadfile {} {
    focus .filelist.textent.txt
 }
 
+proc xcircuit::promptimportspice {} {
+   .filelist.bbar.okay configure -command \
+	{xcircuit::page import spice \
+	[.filelist.textent.txt get]; wm withdraw .filelist}
+   .filelist.listwin.win configure -data "spice"
+   .filelist.textent.title.field configure -text "Select SPICE file to import:"
+   wm deiconify .filelist
+   focus .filelist.textent.txt
+}
+
 proc xcircuit::promptimportfile {} {
    .filelist.bbar.okay configure -command \
-	{xcircuit::page import [.filelist.textent.txt get]; wm withdraw .filelist}
+	{xcircuit::page import xcircuit \
+	[.filelist.textent.txt get]; wm withdraw .filelist}
    .filelist.listwin.win configure -data "ps"
    .filelist.textent.title.field configure -text "Select file to import:"
    wm deiconify .filelist
@@ -1070,7 +1081,8 @@ proc xcircuit::promptimportfile {} {
 
 proc xcircuit::promptimportbackground {} {
    .filelist.bbar.okay configure -command \
-	{xcircuit::page background [.filelist.textent.txt get]; wm withdraw .filelist}
+	{xcircuit::page import background \
+	[.filelist.textent.txt get]; wm withdraw .filelist}
    .filelist.listwin.win configure -data "ps"
    .filelist.textent.title.field configure -text "Select file to use as background:"
    wm deiconify .filelist
@@ -1391,6 +1403,9 @@ set m [menu .xcircuit.menubar.filebutton.filemenu -tearoff 0]
 $m add command -label "Read XCircuit File" -command {xcircuit::promptloadfile}
 $m add command -label "Import XCircuit PS" -command {xcircuit::promptimportfile}
 $m add command -label "Import background PS" -command {xcircuit::promptimportbackground}
+if {![catch {set XCIRCUIT_ASG}]} {
+   $m add command -label "Import SPICE Deck" -command {xcircuit::promptimportspice}
+}
 $m add command -label "Execute Script" -command {xcircuit::promptexecscript}
 $m add command -label "Tcl Console" -command {xcircuit::raiseconsole}
 $m add command -label "Write XCircuit PS" -command {xcircuit::promptsavepage}
