@@ -47,6 +47,10 @@ extern char _STR[150];
 extern short fontcount;
 extern fontinfo *fonts;
 
+/*------------------------------------------------------*/
+/* Check if a library exists				*/
+/*-------------------------------------------------------*/
+
 /*---------------------------------------------------------*/
 /* Find the Helvetica font for use in labeling the objects */
 /*---------------------------------------------------------*/
@@ -273,6 +277,22 @@ int is_library(objectptr thisobj)
    return -1;
 }
 
+/*------------------------------------------------------*/
+/* Check if a library (given by name) exists.  If it	*/
+/* does, return the library number.  If not, return -1	*/
+/*------------------------------------------------------*/
+
+int check_library(char *libname)
+{
+   int i;
+   
+   for (i = 0; i < xobjs.numlibs; i++)
+      if (!strcmp(xobjs.libtop[i + LIBRARY]->thisobject->name, libname))
+	 return i;
+
+   return -1;
+}
+
 /*------------------------------------------------------*/
 /* ButtonPress handler during page catalog viewing mode */
 /*------------------------------------------------------*/
